<?php

// @file relevance.admin.inc


/**
 * Copyleft (C) 2008 by Cooperativa Laudelina Campos Melo.
 * Author(s): Fernao Lopes
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY. See the LICENSE.txt file for more details.
 *
 **/


function relevance_settings_form() {

  // vocabularies
  $vocs = taxonomy_get_vocabularies();
  $settings_voc = relevance_get_settings('voc');
  
  $form["relevance_voc"] = array(
    '#tree' => TRUE,
    '#type' => 'fieldset',
    '#title' => t('Vocabularies'),
    '#description' => ('Configuration for vocabularies. You should enable a vocabulary and then set a multiplier factor for it. Values: 1-9.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#theme' => 'relevance_settings_form',
  );
  
  foreach ($vocs as $vid => $voc) {
    $form['relevance_voc'][$vid]['name'] = array(
      '#type' => 'item',
      '#value' => $voc->name,
    );    
    $form["relevance_voc"][$vid]["enabled"] = array(
      '#type' => 'checkbox',
      '#default_value' => $settings_voc[$vid]['enabled'],
     );
    $form["relevance_voc"][$vid]["factor"] = array(
      '#type' => 'textfield',
      '#size' => 1,
      '#maxlength' => 3,
      '#default_value' => $settings_voc[$vid]['factor'],
    );
    next($settings_voc);
  }
  
  // stats
  $form["relevance_stat"] = array(
    '#type' => 'fieldset',
    '#title' => t('Statistics'),
    '#description' => ('Configuration for statistics.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  
  $form["relevance_stat"]["relevance_stat_enabled"] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable statistics'),
    '#default_value' => variable_get('relevance_stat_enabled', FALSE),
  );

  $form["relevance_stat"]["relevance_stat_factor"] = array(
    '#type' => 'textfield',
    '#title' => t('Factor'),
    '#size' => 1,
    '#maxlength' => 1,
    '#default_value' => variable_get('relevance_stat_factor', FALSE),
  );
  
  // dates 
  $settings_date = relevance_get_settings('date');
  $form["relevance_date"] = array(
    '#tree' => TRUE,
    '#type' => 'fieldset',
    '#title' => t('Dates'),
    '#description' => ('Configuration for periods. You should enable the granularity of it, by setting different periods of time and their importance, by the setting factor (1-9).'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#theme' => 'relevance_settings_form',
    );
  foreach ($settings_date as $period => $date) {
    $form['relevance_date'][$period]['name'] = array(
      '#type' => 'item',
      '#value' => $period,
    );    
    $form["relevance_date"][$period]["enabled"] = array(
      '#type' => 'checkbox',
      '#default_value' => $date["enabled"],
     );
    $form["relevance_date"][$period]["factor"] = array(
      '#type' => 'textfield',
      '#size' => 1,
      '#maxlength' => 1,
      '#default_value' => $date["factor"],
    );
  }
  
  // display
  $form["relevance_display"] = array(
    '#type' => 'fieldset',
    '#title' => t('Display options'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form["relevance_display"]["relevance_display_itens"] = array(
    '#type' => 'textfield',
    '#title' => t('Itens to display'),
    '#size' => 1,
    '#maxlength' => 2,
    '#description' => t('1 to 10'),
    '#default_value' => variable_get('relevance_display_itens', 5),
  );
  
  $form["relevance_display"]["relevance_display_score"] = array(
    '#type' => 'checkbox',
    '#title' => t('Display relevance score'),
    '#default_value' => variable_get('relevance_display_score', 5),
  );
  return system_settings_form($form);
}

/**
 * Format the display of vocabularies as table
 */
function theme_relevance_settings_form($form_element) {
  $rows = array();
  foreach (element_children($form_element) as $key) {
    $row = array();
    if (is_array($form_element[$key]['name'])) {
      $row[] = drupal_render($form_element[$key]['name']);
      $row[] = drupal_render($form_element[$key]['enabled']);
      $row[] = drupal_render($form_element[$key]['factor']);
    }
    $rows[] = $row;
  }
  $header = array(t('Type'), t('Enabled'), t('Factor'));

  $output = theme('table', $header, $rows);
  $output .= drupal_render($form_element);
  return $output;
}
